==> production-demo-20260209_092413.tar.gz: var/www/html/production-demo/var/tmp/twig/af/af1d53b4094fa9112334d919719ca1ff.php <==
<?php

use Twig\Environment;
use Twig\Error\LoaderError;
use Twig\Error\RuntimeError;
use Twig\Extension\CoreExtension;
use Twig\Extension\SandboxExtension;
use Twig\Markup;
use Twig\Sandbox\SecurityError;
use Twig\Sandbox\SecurityNotAllowedTagError;
use Twig\Sandbox\SecurityNotAllowedFilterError;
use Twig\Sandbox\SecurityNotAllowedFunctionError;
use Twig\Source;
use Twig\Template;
use Twig\TemplateWrapper;

/* @bundles/CoreBundle/Loader/EnvVars/ElFinderEnvVars.php */
class __TwigTemplate_4a26718be38668417441ebc6a7acc12b extends Template
{
    private Source $source;
    /**
     * @var array<string, Template>
     */
    private array $macros = [];

    public function __construct(Environment $env)
    {
        parent::__construct($env);

        $this->source = $this->getSourceContext();

        $this->parent = false;

        $this->blocks = [
        ];
    }

    protected function doDisplay(array $context, array $blocks = []): iterable
    {
        $macros = $this->macros;
        // line 1
        yield "<?php

namespace Mautic\\CoreBundle\\Loader\\EnvVars;

use Symfony\\Component\\HttpFoundation\\ParameterBag;

class ElFinderEnvVars implements EnvVarsInterface
{
    public static function load(ParameterBag \$config, ParameterBag \$defaultConfig, ParameterBag \$envVars): void
    {
        \$root = rtrim((string) \$defaultConfig->get('local_root'), '/') ?: '%kernel.project_dir%';

        \$relativeImageFolderPath = trim((string) \$config->get('image_path'), '/');
        \$absoluteImageFolderPath = \$root.'/'.\$relativeImageFolderPath;
        \$envVars->set('MAUTIC_EL_FINDER_PATH', \$absoluteImageFolderPath);

        \$url = rtrim((string) \$config->get('site_url'), '/').'/'.\$relativeImageFolderPath;
        \$envVars->set('MAUTIC_EL_FINDER_URL', \$url);
    }
}
";
        yield from [];
    }

    /**
     * @codeCoverageIgnore
     */
    public function getTemplateName(): string
    {
        return "@bundles/CoreBundle/Loader/EnvVars/ElFinderEnvVars.php";
    }

    /**
     * @codeCoverageIgnore
     */
    public function getDebugInfo(): array
    {
        return array (  42 => 1,);
    }

    public function getSourceContext(): Source
    {
        return new Source("", "@bundles/CoreBundle/Loader/EnvVars/ElFinderEnvVars.php", "/var/www/html/mauticGIT-Test/app/bundles/CoreBundle/Loader/EnvVars/ElFinderEnvVars.php");
    }
}

==> production-demo-20260209_093043.tar.gz: var/www/html/production-demo/var/tmp/twig/af/af1d53b4094fa9112334d919719ca1ff.php <==
<?php

use Twig\Environment;
use Twig\Error\LoaderError;
use Twig\Error\RuntimeError;
use Twig\Extension\CoreExtension;
use Twig\Extension\SandboxExtension;
use Twig\Markup;
use Twig\Sandbox\SecurityError;
use Twig\Sandbox\SecurityNotAllowedTagError;
use Twig\Sandbox\SecurityNotAllowedFilterError;
use Twig\Sandbox\SecurityNotAllowedFunctionError;
use Twig\Source;
use Twig\Template;
use Twig\TemplateWrapper;

/* @bundles/CoreBundle/Loader/EnvVars/ElFinderEnvVars.php */
class __TwigTemplate_4a26718be38668417441ebc6a7acc12b extends Template
{
    private Source $source;
    /**
     * @var array<string, Template>
     */
    private array $macros = [];

    public function __construct(Environment $env)
    {
        parent::__construct($env);

        $this->source = $this->getSourceContext();

        $this->parent = false;

        $this->blocks = [
        ];
    }

    protected function doDisplay(array $context, array $blocks = []): iterable
    {
        $macros = $this->macros;
        // line 1
        yield "<?php

namespace Mautic\\CoreBundle\\Loader\\EnvVars;

use Symfony\\Component\\HttpFoundation\\ParameterBag;

class ElFinderEnvVars implements EnvVarsInterface
{
    public static function load(ParameterBag \$config, ParameterBag \$defaultConfig, ParameterBag \$envVars): void
    {
        \$root = rtrim((string) \$defaultConfig->get('local_root'), '/') ?: '%kernel.project_dir%';

        \$relativeImageFolderPath = trim((string) \$config->get('image_path'), '/');
        \$absoluteImageFolderPath = \$root.'/'.\$relativeImageFolderPath;
        \$envVars->set('MAUTIC_EL_FINDER_PATH', \$absoluteImageFolderPath);

        \$url = rtrim((string) \$config->get('site_url'), '/').'/'.\$relativeImageFolderPath;
        \$envVars->set('MAUTIC_EL_FINDER_URL', \$url);
    }
}
";
        yield from [];
    }

    /**
     * @codeCoverageIgnore
     */
    public function getTemplateName(): string
    {
        return "@bundles/CoreBundle/Loader/EnvVars/ElFinderEnvVars.php";
    }

    /**
     * @codeCoverageIgnore
     */
    public function getDebugInfo(): array
    {
        return array (  42 => 1,);
    }

    public function getSourceContext(): Source
    {
        return new Source("", "@bundles/CoreBundle/Loader/EnvVars/ElFinderEnvVars.php", "/var/www/html/production-demo/app/bundles/CoreBundle/Loader/EnvVars/ElFinderEnvVars.php");
    }
}
